Coverage report

# Coverage report: 83%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 803 | 138 | 0 | 83%
src/hatch_ci/__init__.py | 3 | 1 | 0 | 67%
src/hatch_ci/_support.py | 63 | 63 | 0 | 0%
src/hatch_ci/cli.py | 72 | 10 | 0 | 86%
src/hatch_ci/code.py | 70 | 3 | 0 | 96%
src/hatch_ci/common.py | 4 | 1 | 0 | 75%
src/hatch_ci/exceptions.py | 27 | 1 | 0 | 96%
src/hatch_ci/fileos.py | 102 | 11 | 0 | 89%
src/hatch_ci/hook_build.py | 42 | 10 | 0 | 76%
src/hatch_ci/hook_metadata.py | 0 | 0 | 0 | 100%
src/hatch_ci/hook_version.py | 18 | 2 | 0 | 89%
src/hatch_ci/hooks.py | 10 | 1 | 0 | 90%
src/hatch_ci/scm.py | 173 | 12 | 0 | 93%
src/hatch_ci/script.py | 72 | 11 | 0 | 85%
src/hatch_ci/text.py | 16 | 1 | 0 | 94%
src/hatch_ci/tools.py | 131 | 11 | 0 | 92%

No items found using the specified filter.